==> 1.2.1.tar.gz: gonuma/SECURITY.md <==
# Security Policy

## Supported releases

- Only the most recent current release is **_SUPPORTED_**.**☨**

  [![GitHubRelease](https://img.shields.io/github/release/johnsonjh/gonuma.svg)](https://github.com/johnsonjh/gonuma/releases/)

- **☨** Support is offered on a **best-effort** basis **ONLY**.

```text
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

- Pre-release versions and past releases are **_NOT SUPPORTED_**.

## Report a security vulnerability

- Create a new issue at [Gridfinity GitLab](https://gitlab.gridfinity.com/go/gonuma/-/issues)

  - Check "_This issue is confidential and should only be visible to team members with at least Reporter access._"

  - Or, send a **PGP-encrypted** email to \<[mailto:jeff@gridfinity.com](mailto:jeff@gridfinity.com)\>

```text
-----BEGIN PGP PUBLIC KEY BLOCK-----
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=JIQ0
-----END PGP PUBLIC KEY BLOCK-----
```

==> 1.2.3.tar.gz: gonuma/SECURITY.md <==
# Security Policy

## Supported releases

- Only the most recent current release is **_SUPPORTED_**.**☨**

  [![GitHubRelease](https://img.shields.io/github/gridfinity/gonuma.svg)](https://github.com/gridfinity/gonuma/releases/)

- **☨** Support is offered on a **best-effort** basis **ONLY**.

```text
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

- Pre-release versions and past releases are **_NOT SUPPORTED_**.

## Report a security vulnerability

- Create a new issue at [Gridfinity GitLab](https://gitlab.gridfinity.com/go/gonuma/-/issues)

  - Check "_This issue is confidential and should only be visible to team members with at least Reporter access._"

  - Or, send a **PGP-encrypted** email to \<[jeff@gridfinity.com](mailto:jeff@gridfinity.com)\>

```text
-----BEGIN PGP PUBLIC KEY BLOCK-----
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=JIQ0
-----END PGP PUBLIC KEY BLOCK-----
```
